@@ -124,6 +124,8 @@ pub(crate) fn parse_l2(
         pair: pair.clone(),
         msg_type: MessageType::L2Event,
         timestamp,
+        seq_id: None,
+        prev_seq_id: None,
         asks: Vec::new(),
         bids: Vec::new(),
         snapshot,
