@@ -625,6 +625,8 @@ pub(crate) fn parse_l2(
         pair: pair.clone(),
         msg_type: MessageType::L2Event,
         timestamp,
+        seq_id: None,
+        prev_seq_id: None,
         asks: ws_msg
             .data
             .iter()
