@@ -145,6 +145,8 @@ pub(crate) fn parse_l2(market_type: MarketType, msg: &str) -> Result<Vec<OrderBo
                 pair,
                 msg_type: MessageType::L2Event,
                 timestamp,
+                seq_id: None,
+                prev_seq_id: None,
                 asks: orderbook_snapshot
                     .asks
                     .iter()
@@ -209,6 +211,8 @@ pub(crate) fn parse_l2(market_type: MarketType, msg: &str) -> Result<Vec<OrderBo
                 pair,
                 msg_type: MessageType::L2Event,
                 timestamp,
+                seq_id: None,
+                prev_seq_id: None,
                 asks,
                 bids,
                 snapshot,
